<?php

namespace Drupal\Tests\block_inactive_users\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\block_inactive_users\InactiveUsersHandler;
use Drupal\Core\Logger\LoggerChannelFactory;

/**
 * Simple test to ensure that asserts pass.
 *
 * @group block_inactive_users
 */
class InactiveUsersHandlerTest extends UnitTestCase {
  const FORM_SETTINGS_CONFIG_OBJ_NAME = "block_inactive_users.settings";
  const LOGGER_CHANNEL = "block_inactive_users";

  protected $configFactoryService;
  protected $logger;

  /**
   * Before a test method is run, setUp() is invoked.
   */
  public function setUp() {

    parent::setUp();

    $container = new ContainerBuilder();
    $this->configFactoryService = $this->getConfigFactoryStub([]);
    $this->logger = $this->getLoggerFactoryMock();
    $container->set('config.factory', $this->configFactoryService);
    $container->set('logger.factory', $this->logger);
    \Drupal::setContainer($container);

  }

  /**
   * Utility function for getting a LoggerChannelFactory service.
   */
  private function getLoggerFactoryMock() {

    $loggerChannel = $this->getMockBuilder('Drupal\Core\Logger\LoggerChannel')
      ->disableOriginalConstructor()
      ->getMock();
    $loggerChannel->expects($this->any())
      ->method('error')
      ->will($this->returnValue(''));

    $loggerChannelFactory = $this->getMockBuilder('Drupal\Core\Logger\LoggerChannelFactory')
      ->disableOriginalConstructor()
      ->getMock();
    $loggerChannelFactory->expects($this->any())
      ->method('get')
      ->will($this->returnValue($loggerChannel));
    return $loggerChannelFactory;
  }

  /**
   * @covers  \Drupal\block_inactive_users\InactiveUsersHandler::disableInactiveUsersStatus
   *
   * Finds user idle users and disabled them
   */
  public function testDisableInactiveUsersStatus() {

    $user = $this->getMockBuilder('Drupal\user\Entity\User')
      ->disableOriginalConstructor()
      ->getMock();

    $user->expects($this->any())
      ->method('isActive')
      ->will($this->returnValue(FALSE));

    $usersHandler = new InactiveUsersHandler(\Drupal::configFactory(), new LoggerChannelFactory());
    $v = $usersHandler->disableInactiveUsersStatus($user, FALSE);
    $this->assertNotEmpty($v);
    $this->assertNotTrue($v->isActive());
  }

}
